@@ -1,5 +1,7 @@
 """
-Main interface for es service client
+Type annotations for es service client.
+
+[Open documentation](./client.md)
 
 Usage::
 
@@ -22,7 +24,9 @@ from mypy_boto3_es.paginator import (
     ListElasticsearchInstanceTypesPaginator,
     ListElasticsearchVersionsPaginator,
 )
-from mypy_boto3_es.type_defs import (
+
+from .literals import ESPartitionInstanceType, LogType
+from .type_defs import (
     AcceptInboundCrossClusterSearchConnectionResponseTypeDef,
     AdvancedSecurityOptionsInputTypeDef,
     AssociatePackageResponseTypeDef,
@@ -113,7 +117,8 @@ class Exceptions:
 
 class ElasticsearchServiceClient:
     """
-    [ElasticsearchService.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.56/reference/services/es.html#ElasticsearchService.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/es.html#ElasticsearchService.Client)
+    [Show boto3-stubs documentation](./client.md)
     """
 
     meta: ClientMeta
@@ -123,29 +128,34 @@ class ElasticsearchServiceClient:
         self, CrossClusterSearchConnectionId: str
     ) -> AcceptInboundCrossClusterSearchConnectionResponseTypeDef:
         """
-        [Client.accept_inbound_cross_cluster_search_connection documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.56/reference/services/es.html#ElasticsearchService.Client.accept_inbound_cross_cluster_search_connection)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/es.html#ElasticsearchService.Client.accept_inbound_cross_cluster_search_connection)
+        [Show boto3-stubs documentation](./client.md#accept-inbound-cross-cluster-search-connection)
         """
 
     def add_tags(self, ARN: str, TagList: List["TagTypeDef"]) -> None:
         """
-        [Client.add_tags documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.56/reference/services/es.html#ElasticsearchService.Client.add_tags)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/es.html#ElasticsearchService.Client.add_tags)
+        [Show boto3-stubs documentation](./client.md#add-tags)
         """
 
     def associate_package(self, PackageID: str, DomainName: str) -> AssociatePackageResponseTypeDef:
         """
-        [Client.associate_package documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.56/reference/services/es.html#ElasticsearchService.Client.associate_package)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/es.html#ElasticsearchService.Client.associate_package)
+        [Show boto3-stubs documentation](./client.md#associate-package)
         """
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.56/reference/services/es.html#ElasticsearchService.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/es.html#ElasticsearchService.Client.can_paginate)
+        [Show boto3-stubs documentation](./client.md#can-paginate)
         """
 
     def cancel_elasticsearch_service_software_update(
         self, DomainName: str
     ) -> CancelElasticsearchServiceSoftwareUpdateResponseTypeDef:
         """
-        [Client.cancel_elasticsearch_service_software_update documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.56/reference/services/es.html#ElasticsearchService.Client.cancel_elasticsearch_service_software_update)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/es.html#ElasticsearchService.Client.cancel_elasticsearch_service_software_update)
+        [Show boto3-stubs documentation](./client.md#cancel-elasticsearch-service-software-update)
         """
 
     def create_elasticsearch_domain(
@@ -161,17 +171,15 @@ class ElasticsearchServiceClient:
         EncryptionAtRestOptions: "EncryptionAtRestOptionsTypeDef" = None,
         NodeToNodeEncryptionOptions: "NodeToNodeEncryptionOptionsTypeDef" = None,
         AdvancedOptions: Dict[str, str] = None,
-        LogPublishingOptions: Dict[
-            Literal["INDEX_SLOW_LOGS", "SEARCH_SLOW_LOGS", "ES_APPLICATION_LOGS", "AUDIT_LOGS"],
-            "LogPublishingOptionTypeDef",
-        ] = None,
+        LogPublishingOptions: Dict[LogType, "LogPublishingOptionTypeDef"] = None,
         DomainEndpointOptions: "DomainEndpointOptionsTypeDef" = None,
         AdvancedSecurityOptions: AdvancedSecurityOptionsInputTypeDef = None,
         AutoTuneOptions: AutoTuneOptionsInputTypeDef = None,
         TagList: List["TagTypeDef"] = None,
     ) -> CreateElasticsearchDomainResponseTypeDef:
         """
-        [Client.create_elasticsearch_domain documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.56/reference/services/es.html#ElasticsearchService.Client.create_elasticsearch_domain)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/es.html#ElasticsearchService.Client.create_elasticsearch_domain)
+        [Show boto3-stubs documentation](./client.md#create-elasticsearch-domain)
         """
 
     def create_outbound_cross_cluster_search_connection(
@@ -181,7 +189,8 @@ class ElasticsearchServiceClient:
         ConnectionAlias: str,
     ) -> CreateOutboundCrossClusterSearchConnectionResponseTypeDef:
         """
-        [Client.create_outbound_cross_cluster_search_connection documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.56/reference/services/es.html#ElasticsearchService.Client.create_outbound_cross_cluster_search_connection)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/es.html#ElasticsearchService.Client.create_outbound_cross_cluster_search_connection)
+        [Show boto3-stubs documentation](./client.md#create-outbound-cross-cluster-search-connection)
         """
 
     def create_package(
@@ -192,149 +201,103 @@ class ElasticsearchServiceClient:
         PackageDescription: str = None,
     ) -> CreatePackageResponseTypeDef:
         """
-        [Client.create_package documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.56/reference/services/es.html#ElasticsearchService.Client.create_package)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/es.html#ElasticsearchService.Client.create_package)
+        [Show boto3-stubs documentation](./client.md#create-package)
         """
 
     def delete_elasticsearch_domain(
         self, DomainName: str
     ) -> DeleteElasticsearchDomainResponseTypeDef:
         """
-        [Client.delete_elasticsearch_domain documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.56/reference/services/es.html#ElasticsearchService.Client.delete_elasticsearch_domain)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/es.html#ElasticsearchService.Client.delete_elasticsearch_domain)
+        [Show boto3-stubs documentation](./client.md#delete-elasticsearch-domain)
         """
 
     def delete_elasticsearch_service_role(self) -> None:
         """
-        [Client.delete_elasticsearch_service_role documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.56/reference/services/es.html#ElasticsearchService.Client.delete_elasticsearch_service_role)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/es.html#ElasticsearchService.Client.delete_elasticsearch_service_role)
+        [Show boto3-stubs documentation](./client.md#delete-elasticsearch-service-role)
         """
 
     def delete_inbound_cross_cluster_search_connection(
         self, CrossClusterSearchConnectionId: str
     ) -> DeleteInboundCrossClusterSearchConnectionResponseTypeDef:
         """
-        [Client.delete_inbound_cross_cluster_search_connection documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.56/reference/services/es.html#ElasticsearchService.Client.delete_inbound_cross_cluster_search_connection)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/es.html#ElasticsearchService.Client.delete_inbound_cross_cluster_search_connection)
+        [Show boto3-stubs documentation](./client.md#delete-inbound-cross-cluster-search-connection)
         """
 
     def delete_outbound_cross_cluster_search_connection(
         self, CrossClusterSearchConnectionId: str
     ) -> DeleteOutboundCrossClusterSearchConnectionResponseTypeDef:
         """
-        [Client.delete_outbound_cross_cluster_search_connection documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.56/reference/services/es.html#ElasticsearchService.Client.delete_outbound_cross_cluster_search_connection)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/es.html#ElasticsearchService.Client.delete_outbound_cross_cluster_search_connection)
+        [Show boto3-stubs documentation](./client.md#delete-outbound-cross-cluster-search-connection)
         """
 
     def delete_package(self, PackageID: str) -> DeletePackageResponseTypeDef:
         """
-        [Client.delete_package documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.56/reference/services/es.html#ElasticsearchService.Client.delete_package)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/es.html#ElasticsearchService.Client.delete_package)
+        [Show boto3-stubs documentation](./client.md#delete-package)
         """
 
     def describe_domain_auto_tunes(
         self, DomainName: str, MaxResults: int = None, NextToken: str = None
     ) -> DescribeDomainAutoTunesResponseTypeDef:
         """
-        [Client.describe_domain_auto_tunes documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.56/reference/services/es.html#ElasticsearchService.Client.describe_domain_auto_tunes)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/es.html#ElasticsearchService.Client.describe_domain_auto_tunes)
+        [Show boto3-stubs documentation](./client.md#describe-domain-auto-tunes)
         """
 
     def describe_elasticsearch_domain(
         self, DomainName: str
     ) -> DescribeElasticsearchDomainResponseTypeDef:
         """
-        [Client.describe_elasticsearch_domain documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.56/reference/services/es.html#ElasticsearchService.Client.describe_elasticsearch_domain)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/es.html#ElasticsearchService.Client.describe_elasticsearch_domain)
+        [Show boto3-stubs documentation](./client.md#describe-elasticsearch-domain)
         """
 
     def describe_elasticsearch_domain_config(
         self, DomainName: str
     ) -> DescribeElasticsearchDomainConfigResponseTypeDef:
         """
-        [Client.describe_elasticsearch_domain_config documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.56/reference/services/es.html#ElasticsearchService.Client.describe_elasticsearch_domain_config)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/es.html#ElasticsearchService.Client.describe_elasticsearch_domain_config)
+        [Show boto3-stubs documentation](./client.md#describe-elasticsearch-domain-config)
         """
 
     def describe_elasticsearch_domains(
         self, DomainNames: List[str]
     ) -> DescribeElasticsearchDomainsResponseTypeDef:
         """
-        [Client.describe_elasticsearch_domains documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.56/reference/services/es.html#ElasticsearchService.Client.describe_elasticsearch_domains)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/es.html#ElasticsearchService.Client.describe_elasticsearch_domains)
+        [Show boto3-stubs documentation](./client.md#describe-elasticsearch-domains)
         """
 
     def describe_elasticsearch_instance_type_limits(
         self,
-        InstanceType: Literal[
-            "m3.medium.elasticsearch",
-            "m3.large.elasticsearch",
-            "m3.xlarge.elasticsearch",
-            "m3.2xlarge.elasticsearch",
-            "m4.large.elasticsearch",
-            "m4.xlarge.elasticsearch",
-            "m4.2xlarge.elasticsearch",
-            "m4.4xlarge.elasticsearch",
-            "m4.10xlarge.elasticsearch",
-            "m5.large.elasticsearch",
-            "m5.xlarge.elasticsearch",
-            "m5.2xlarge.elasticsearch",
-            "m5.4xlarge.elasticsearch",
-            "m5.12xlarge.elasticsearch",
-            "r5.large.elasticsearch",
-            "r5.xlarge.elasticsearch",
-            "r5.2xlarge.elasticsearch",
-            "r5.4xlarge.elasticsearch",
-            "r5.12xlarge.elasticsearch",
-            "c5.large.elasticsearch",
-            "c5.xlarge.elasticsearch",
-            "c5.2xlarge.elasticsearch",
-            "c5.4xlarge.elasticsearch",
-            "c5.9xlarge.elasticsearch",
-            "c5.18xlarge.elasticsearch",
-            "ultrawarm1.medium.elasticsearch",
-            "ultrawarm1.large.elasticsearch",
-            "t2.micro.elasticsearch",
-            "t2.small.elasticsearch",
-            "t2.medium.elasticsearch",
-            "r3.large.elasticsearch",
-            "r3.xlarge.elasticsearch",
-            "r3.2xlarge.elasticsearch",
-            "r3.4xlarge.elasticsearch",
-            "r3.8xlarge.elasticsearch",
-            "i2.xlarge.elasticsearch",
-            "i2.2xlarge.elasticsearch",
-            "d2.xlarge.elasticsearch",
-            "d2.2xlarge.elasticsearch",
-            "d2.4xlarge.elasticsearch",
-            "d2.8xlarge.elasticsearch",
-            "c4.large.elasticsearch",
-            "c4.xlarge.elasticsearch",
-            "c4.2xlarge.elasticsearch",
-            "c4.4xlarge.elasticsearch",
-            "c4.8xlarge.elasticsearch",
-            "r4.large.elasticsearch",
-            "r4.xlarge.elasticsearch",
-            "r4.2xlarge.elasticsearch",
-            "r4.4xlarge.elasticsearch",
-            "r4.8xlarge.elasticsearch",
-            "r4.16xlarge.elasticsearch",
-            "i3.large.elasticsearch",
-            "i3.xlarge.elasticsearch",
-            "i3.2xlarge.elasticsearch",
-            "i3.4xlarge.elasticsearch",
-            "i3.8xlarge.elasticsearch",
-            "i3.16xlarge.elasticsearch",
-        ],
+        InstanceType: ESPartitionInstanceType,
         ElasticsearchVersion: str,
         DomainName: str = None,
     ) -> DescribeElasticsearchInstanceTypeLimitsResponseTypeDef:
         """
-        [Client.describe_elasticsearch_instance_type_limits documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.56/reference/services/es.html#ElasticsearchService.Client.describe_elasticsearch_instance_type_limits)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/es.html#ElasticsearchService.Client.describe_elasticsearch_instance_type_limits)
+        [Show boto3-stubs documentation](./client.md#describe-elasticsearch-instance-type-limits)
         """
 
     def describe_inbound_cross_cluster_search_connections(
         self, Filters: List[FilterTypeDef] = None, MaxResults: int = None, NextToken: str = None
     ) -> DescribeInboundCrossClusterSearchConnectionsResponseTypeDef:
         """
-        [Client.describe_inbound_cross_cluster_search_connections documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.56/reference/services/es.html#ElasticsearchService.Client.describe_inbound_cross_cluster_search_connections)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/es.html#ElasticsearchService.Client.describe_inbound_cross_cluster_search_connections)
+        [Show boto3-stubs documentation](./client.md#describe-inbound-cross-cluster-search-connections)
         """
 
     def describe_outbound_cross_cluster_search_connections(
         self, Filters: List[FilterTypeDef] = None, MaxResults: int = None, NextToken: str = None
     ) -> DescribeOutboundCrossClusterSearchConnectionsResponseTypeDef:
         """
-        [Client.describe_outbound_cross_cluster_search_connections documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.56/reference/services/es.html#ElasticsearchService.Client.describe_outbound_cross_cluster_search_connections)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/es.html#ElasticsearchService.Client.describe_outbound_cross_cluster_search_connections)
+        [Show boto3-stubs documentation](./client.md#describe-outbound-cross-cluster-search-connections)
         """
 
     def describe_packages(
@@ -344,7 +307,8 @@ class ElasticsearchServiceClient:
         NextToken: str = None,
     ) -> DescribePackagesResponseTypeDef:
         """
-        [Client.describe_packages documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.56/reference/services/es.html#ElasticsearchService.Client.describe_packages)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/es.html#ElasticsearchService.Client.describe_packages)
+        [Show boto3-stubs documentation](./client.md#describe-packages)
         """
 
     def describe_reserved_elasticsearch_instance_offerings(
@@ -354,7 +318,8 @@ class ElasticsearchServiceClient:
         NextToken: str = None,
     ) -> DescribeReservedElasticsearchInstanceOfferingsResponseTypeDef:
         """
-        [Client.describe_reserved_elasticsearch_instance_offerings documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.56/reference/services/es.html#ElasticsearchService.Client.describe_reserved_elasticsearch_instance_offerings)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/es.html#ElasticsearchService.Client.describe_reserved_elasticsearch_instance_offerings)
+        [Show boto3-stubs documentation](./client.md#describe-reserved-elasticsearch-instance-offerings)
         """
 
     def describe_reserved_elasticsearch_instances(
@@ -364,14 +329,16 @@ class ElasticsearchServiceClient:
         NextToken: str = None,
     ) -> DescribeReservedElasticsearchInstancesResponseTypeDef:
         """
-        [Client.describe_reserved_elasticsearch_instances documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.56/reference/services/es.html#ElasticsearchService.Client.describe_reserved_elasticsearch_instances)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/es.html#ElasticsearchService.Client.describe_reserved_elasticsearch_instances)
+        [Show boto3-stubs documentation](./client.md#describe-reserved-elasticsearch-instances)
         """
 
     def dissociate_package(
         self, PackageID: str, DomainName: str
     ) -> DissociatePackageResponseTypeDef:
         """
-        [Client.dissociate_package documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.56/reference/services/es.html#ElasticsearchService.Client.dissociate_package)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/es.html#ElasticsearchService.Client.dissociate_package)
+        [Show boto3-stubs documentation](./client.md#dissociate-package)
         """
 
     def generate_presigned_url(
@@ -382,45 +349,52 @@ class ElasticsearchServiceClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.56/reference/services/es.html#ElasticsearchService.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/es.html#ElasticsearchService.Client.generate_presigned_url)
+        [Show boto3-stubs documentation](./client.md#generate-presigned-url)
         """
 
     def get_compatible_elasticsearch_versions(
         self, DomainName: str = None
     ) -> GetCompatibleElasticsearchVersionsResponseTypeDef:
         """
-        [Client.get_compatible_elasticsearch_versions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.56/reference/services/es.html#ElasticsearchService.Client.get_compatible_elasticsearch_versions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/es.html#ElasticsearchService.Client.get_compatible_elasticsearch_versions)
+        [Show boto3-stubs documentation](./client.md#get-compatible-elasticsearch-versions)
         """
 
     def get_package_version_history(
         self, PackageID: str, MaxResults: int = None, NextToken: str = None
     ) -> GetPackageVersionHistoryResponseTypeDef:
         """
-        [Client.get_package_version_history documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.56/reference/services/es.html#ElasticsearchService.Client.get_package_version_history)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/es.html#ElasticsearchService.Client.get_package_version_history)
+        [Show boto3-stubs documentation](./client.md#get-package-version-history)
         """
 
     def get_upgrade_history(
         self, DomainName: str, MaxResults: int = None, NextToken: str = None
     ) -> GetUpgradeHistoryResponseTypeDef:
         """
-        [Client.get_upgrade_history documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.56/reference/services/es.html#ElasticsearchService.Client.get_upgrade_history)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/es.html#ElasticsearchService.Client.get_upgrade_history)
+        [Show boto3-stubs documentation](./client.md#get-upgrade-history)
         """
 
     def get_upgrade_status(self, DomainName: str) -> GetUpgradeStatusResponseTypeDef:
         """
-        [Client.get_upgrade_status documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.56/reference/services/es.html#ElasticsearchService.Client.get_upgrade_status)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/es.html#ElasticsearchService.Client.get_upgrade_status)
+        [Show boto3-stubs documentation](./client.md#get-upgrade-status)
         """
 
     def list_domain_names(self) -> ListDomainNamesResponseTypeDef:
         """
-        [Client.list_domain_names documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.56/reference/services/es.html#ElasticsearchService.Client.list_domain_names)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/es.html#ElasticsearchService.Client.list_domain_names)
+        [Show boto3-stubs documentation](./client.md#list-domain-names)
         """
 
     def list_domains_for_package(
         self, PackageID: str, MaxResults: int = None, NextToken: str = None
     ) -> ListDomainsForPackageResponseTypeDef:
         """
-        [Client.list_domains_for_package documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.56/reference/services/es.html#ElasticsearchService.Client.list_domains_for_package)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/es.html#ElasticsearchService.Client.list_domains_for_package)
+        [Show boto3-stubs documentation](./client.md#list-domains-for-package)
         """
 
     def list_elasticsearch_instance_types(
@@ -431,26 +405,30 @@ class ElasticsearchServiceClient:
         NextToken: str = None,
     ) -> ListElasticsearchInstanceTypesResponseTypeDef:
         """
-        [Client.list_elasticsearch_instance_types documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.56/reference/services/es.html#ElasticsearchService.Client.list_elasticsearch_instance_types)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/es.html#ElasticsearchService.Client.list_elasticsearch_instance_types)
+        [Show boto3-stubs documentation](./client.md#list-elasticsearch-instance-types)
         """
 
     def list_elasticsearch_versions(
         self, MaxResults: int = None, NextToken: str = None
     ) -> ListElasticsearchVersionsResponseTypeDef:
         """
-        [Client.list_elasticsearch_versions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.56/reference/services/es.html#ElasticsearchService.Client.list_elasticsearch_versions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/es.html#ElasticsearchService.Client.list_elasticsearch_versions)
+        [Show boto3-stubs documentation](./client.md#list-elasticsearch-versions)
         """
 
     def list_packages_for_domain(
         self, DomainName: str, MaxResults: int = None, NextToken: str = None
     ) -> ListPackagesForDomainResponseTypeDef:
         """
-        [Client.list_packages_for_domain documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.56/reference/services/es.html#ElasticsearchService.Client.list_packages_for_domain)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/es.html#ElasticsearchService.Client.list_packages_for_domain)
+        [Show boto3-stubs documentation](./client.md#list-packages-for-domain)
         """
 
     def list_tags(self, ARN: str) -> ListTagsResponseTypeDef:
         """
-        [Client.list_tags documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.56/reference/services/es.html#ElasticsearchService.Client.list_tags)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/es.html#ElasticsearchService.Client.list_tags)
+        [Show boto3-stubs documentation](./client.md#list-tags)
         """
 
     def purchase_reserved_elasticsearch_instance_offering(
@@ -460,26 +438,30 @@ class ElasticsearchServiceClient:
         InstanceCount: int = None,
     ) -> PurchaseReservedElasticsearchInstanceOfferingResponseTypeDef:
         """
-        [Client.purchase_reserved_elasticsearch_instance_offering documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.56/reference/services/es.html#ElasticsearchService.Client.purchase_reserved_elasticsearch_instance_offering)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/es.html#ElasticsearchService.Client.purchase_reserved_elasticsearch_instance_offering)
+        [Show boto3-stubs documentation](./client.md#purchase-reserved-elasticsearch-instance-offering)
         """
 
     def reject_inbound_cross_cluster_search_connection(
         self, CrossClusterSearchConnectionId: str
     ) -> RejectInboundCrossClusterSearchConnectionResponseTypeDef:
         """
-        [Client.reject_inbound_cross_cluster_search_connection documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.56/reference/services/es.html#ElasticsearchService.Client.reject_inbound_cross_cluster_search_connection)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/es.html#ElasticsearchService.Client.reject_inbound_cross_cluster_search_connection)
+        [Show boto3-stubs documentation](./client.md#reject-inbound-cross-cluster-search-connection)
         """
 
     def remove_tags(self, ARN: str, TagKeys: List[str]) -> None:
         """
-        [Client.remove_tags documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.56/reference/services/es.html#ElasticsearchService.Client.remove_tags)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/es.html#ElasticsearchService.Client.remove_tags)
+        [Show boto3-stubs documentation](./client.md#remove-tags)
         """
 
     def start_elasticsearch_service_software_update(
         self, DomainName: str
     ) -> StartElasticsearchServiceSoftwareUpdateResponseTypeDef:
         """
-        [Client.start_elasticsearch_service_software_update documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.56/reference/services/es.html#ElasticsearchService.Client.start_elasticsearch_service_software_update)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/es.html#ElasticsearchService.Client.start_elasticsearch_service_software_update)
+        [Show boto3-stubs documentation](./client.md#start-elasticsearch-service-software-update)
         """
 
     def update_elasticsearch_domain_config(
@@ -492,10 +474,7 @@ class ElasticsearchServiceClient:
         CognitoOptions: "CognitoOptionsTypeDef" = None,
         AdvancedOptions: Dict[str, str] = None,
         AccessPolicies: str = None,
-        LogPublishingOptions: Dict[
-            Literal["INDEX_SLOW_LOGS", "SEARCH_SLOW_LOGS", "ES_APPLICATION_LOGS", "AUDIT_LOGS"],
-            "LogPublishingOptionTypeDef",
-        ] = None,
+        LogPublishingOptions: Dict[LogType, "LogPublishingOptionTypeDef"] = None,
         DomainEndpointOptions: "DomainEndpointOptionsTypeDef" = None,
         AdvancedSecurityOptions: AdvancedSecurityOptionsInputTypeDef = None,
         NodeToNodeEncryptionOptions: "NodeToNodeEncryptionOptionsTypeDef" = None,
@@ -503,7 +482,8 @@ class ElasticsearchServiceClient:
         AutoTuneOptions: "AutoTuneOptionsTypeDef" = None,
     ) -> UpdateElasticsearchDomainConfigResponseTypeDef:
         """
-        [Client.update_elasticsearch_domain_config documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.56/reference/services/es.html#ElasticsearchService.Client.update_elasticsearch_domain_config)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/es.html#ElasticsearchService.Client.update_elasticsearch_domain_config)
+        [Show boto3-stubs documentation](./client.md#update-elasticsearch-domain-config)
         """
 
     def update_package(
@@ -514,14 +494,16 @@ class ElasticsearchServiceClient:
         CommitMessage: str = None,
     ) -> UpdatePackageResponseTypeDef:
         """
-        [Client.update_package documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.56/reference/services/es.html#ElasticsearchService.Client.update_package)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/es.html#ElasticsearchService.Client.update_package)
+        [Show boto3-stubs documentation](./client.md#update-package)
         """
 
     def upgrade_elasticsearch_domain(
         self, DomainName: str, TargetVersion: str, PerformCheckOnly: bool = None
     ) -> UpgradeElasticsearchDomainResponseTypeDef:
         """
-        [Client.upgrade_elasticsearch_domain documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.56/reference/services/es.html#ElasticsearchService.Client.upgrade_elasticsearch_domain)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/es.html#ElasticsearchService.Client.upgrade_elasticsearch_domain)
+        [Show boto3-stubs documentation](./client.md#upgrade-elasticsearch-domain)
         """
 
     @overload
@@ -529,7 +511,7 @@ class ElasticsearchServiceClient:
         self, operation_name: Literal["describe_reserved_elasticsearch_instance_offerings"]
     ) -> DescribeReservedElasticsearchInstanceOfferingsPaginator:
         """
-        [Paginator.DescribeReservedElasticsearchInstanceOfferings documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.56/reference/services/es.html#ElasticsearchService.Paginator.DescribeReservedElasticsearchInstanceOfferings)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/es.html#ElasticsearchService.Paginator.DescribeReservedElasticsearchInstanceOfferings)[Show boto3-stubs documentation](./paginators.md#describereservedelasticsearchinstanceofferingspaginator)
         """
 
     @overload
@@ -537,7 +519,7 @@ class ElasticsearchServiceClient:
         self, operation_name: Literal["describe_reserved_elasticsearch_instances"]
     ) -> DescribeReservedElasticsearchInstancesPaginator:
         """
-        [Paginator.DescribeReservedElasticsearchInstances documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.56/reference/services/es.html#ElasticsearchService.Paginator.DescribeReservedElasticsearchInstances)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/es.html#ElasticsearchService.Paginator.DescribeReservedElasticsearchInstances)[Show boto3-stubs documentation](./paginators.md#describereservedelasticsearchinstancespaginator)
         """
 
     @overload
@@ -545,7 +527,7 @@ class ElasticsearchServiceClient:
         self, operation_name: Literal["get_upgrade_history"]
     ) -> GetUpgradeHistoryPaginator:
         """
-        [Paginator.GetUpgradeHistory documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.56/reference/services/es.html#ElasticsearchService.Paginator.GetUpgradeHistory)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/es.html#ElasticsearchService.Paginator.GetUpgradeHistory)[Show boto3-stubs documentation](./paginators.md#getupgradehistorypaginator)
         """
 
     @overload
@@ -553,7 +535,7 @@ class ElasticsearchServiceClient:
         self, operation_name: Literal["list_elasticsearch_instance_types"]
     ) -> ListElasticsearchInstanceTypesPaginator:
         """
-        [Paginator.ListElasticsearchInstanceTypes documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.56/reference/services/es.html#ElasticsearchService.Paginator.ListElasticsearchInstanceTypes)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/es.html#ElasticsearchService.Paginator.ListElasticsearchInstanceTypes)[Show boto3-stubs documentation](./paginators.md#listelasticsearchinstancetypespaginator)
         """
 
     @overload
@@ -561,5 +543,5 @@ class ElasticsearchServiceClient:
         self, operation_name: Literal["list_elasticsearch_versions"]
     ) -> ListElasticsearchVersionsPaginator:
         """
-        [Paginator.ListElasticsearchVersions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.56/reference/services/es.html#ElasticsearchService.Paginator.ListElasticsearchVersions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/es.html#ElasticsearchService.Paginator.ListElasticsearchVersions)[Show boto3-stubs documentation](./paginators.md#listelasticsearchversionspaginator)
         """
