@@ -1,5 +1,7 @@
 """
-Main interface for es service client paginators.
+Type annotations for es service client paginators.
+
+[Open documentation](./paginators.md)
 
 Usage::
 
@@ -28,7 +30,7 @@ from typing import Iterator
 
 from botocore.paginate import Paginator as Boto3Paginator
 
-from mypy_boto3_es.type_defs import (
+from .type_defs import (
     DescribeReservedElasticsearchInstanceOfferingsResponseTypeDef,
     DescribeReservedElasticsearchInstancesResponseTypeDef,
     GetUpgradeHistoryResponseTypeDef,
@@ -48,7 +50,7 @@ __all__ = (
 
 class DescribeReservedElasticsearchInstanceOfferingsPaginator(Boto3Paginator):
     """
-    [Paginator.DescribeReservedElasticsearchInstanceOfferings documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.56/reference/services/es.html#ElasticsearchService.Paginator.DescribeReservedElasticsearchInstanceOfferings)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/es.html#ElasticsearchService.Paginator.DescribeReservedElasticsearchInstanceOfferings)[Show boto3-stubs documentation](./paginators.md#describereservedelasticsearchinstanceofferingspaginator)
     """
 
     def paginate(
@@ -57,13 +59,14 @@ class DescribeReservedElasticsearchInstanceOfferingsPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[DescribeReservedElasticsearchInstanceOfferingsResponseTypeDef]:
         """
-        [DescribeReservedElasticsearchInstanceOfferings.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.56/reference/services/es.html#ElasticsearchService.Paginator.DescribeReservedElasticsearchInstanceOfferings.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/es.html#ElasticsearchService.Paginator.DescribeReservedElasticsearchInstanceOfferings.paginate)
+        [Show boto3-stubs documentation](./paginators.md#describereservedelasticsearchinstanceofferingspaginator)
         """
 
 
 class DescribeReservedElasticsearchInstancesPaginator(Boto3Paginator):
     """
-    [Paginator.DescribeReservedElasticsearchInstances documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.56/reference/services/es.html#ElasticsearchService.Paginator.DescribeReservedElasticsearchInstances)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/es.html#ElasticsearchService.Paginator.DescribeReservedElasticsearchInstances)[Show boto3-stubs documentation](./paginators.md#describereservedelasticsearchinstancespaginator)
     """
 
     def paginate(
@@ -72,26 +75,28 @@ class DescribeReservedElasticsearchInstancesPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[DescribeReservedElasticsearchInstancesResponseTypeDef]:
         """
-        [DescribeReservedElasticsearchInstances.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.56/reference/services/es.html#ElasticsearchService.Paginator.DescribeReservedElasticsearchInstances.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/es.html#ElasticsearchService.Paginator.DescribeReservedElasticsearchInstances.paginate)
+        [Show boto3-stubs documentation](./paginators.md#describereservedelasticsearchinstancespaginator)
         """
 
 
 class GetUpgradeHistoryPaginator(Boto3Paginator):
     """
-    [Paginator.GetUpgradeHistory documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.56/reference/services/es.html#ElasticsearchService.Paginator.GetUpgradeHistory)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/es.html#ElasticsearchService.Paginator.GetUpgradeHistory)[Show boto3-stubs documentation](./paginators.md#getupgradehistorypaginator)
     """
 
     def paginate(
         self, DomainName: str, PaginationConfig: PaginatorConfigTypeDef = None
     ) -> Iterator[GetUpgradeHistoryResponseTypeDef]:
         """
-        [GetUpgradeHistory.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.56/reference/services/es.html#ElasticsearchService.Paginator.GetUpgradeHistory.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/es.html#ElasticsearchService.Paginator.GetUpgradeHistory.paginate)
+        [Show boto3-stubs documentation](./paginators.md#getupgradehistorypaginator)
         """
 
 
 class ListElasticsearchInstanceTypesPaginator(Boto3Paginator):
     """
-    [Paginator.ListElasticsearchInstanceTypes documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.56/reference/services/es.html#ElasticsearchService.Paginator.ListElasticsearchInstanceTypes)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/es.html#ElasticsearchService.Paginator.ListElasticsearchInstanceTypes)[Show boto3-stubs documentation](./paginators.md#listelasticsearchinstancetypespaginator)
     """
 
     def paginate(
@@ -101,18 +106,20 @@ class ListElasticsearchInstanceTypesPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[ListElasticsearchInstanceTypesResponseTypeDef]:
         """
-        [ListElasticsearchInstanceTypes.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.56/reference/services/es.html#ElasticsearchService.Paginator.ListElasticsearchInstanceTypes.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/es.html#ElasticsearchService.Paginator.ListElasticsearchInstanceTypes.paginate)
+        [Show boto3-stubs documentation](./paginators.md#listelasticsearchinstancetypespaginator)
         """
 
 
 class ListElasticsearchVersionsPaginator(Boto3Paginator):
     """
-    [Paginator.ListElasticsearchVersions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.56/reference/services/es.html#ElasticsearchService.Paginator.ListElasticsearchVersions)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/es.html#ElasticsearchService.Paginator.ListElasticsearchVersions)[Show boto3-stubs documentation](./paginators.md#listelasticsearchversionspaginator)
     """
 
     def paginate(
         self, PaginationConfig: PaginatorConfigTypeDef = None
     ) -> Iterator[ListElasticsearchVersionsResponseTypeDef]:
         """
-        [ListElasticsearchVersions.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.56/reference/services/es.html#ElasticsearchService.Paginator.ListElasticsearchVersions.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/es.html#ElasticsearchService.Paginator.ListElasticsearchVersions.paginate)
+        [Show boto3-stubs documentation](./paginators.md#listelasticsearchversionspaginator)
         """
